==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/qoptions.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include "qwerty.h"
#include "briefedit.h"
#include "dialogs.h"
#include "colordialog.h"
#include "aliasdialog.h"
#include "ctagsdialog.h"
#include "wwwdialog.h"
#include "hashdb.h"
#include "spell.h"
#include "qtutils.h"
#include "busycursor.h"
#include "ctags.h"
#include "bufmgr.h"
#include <qapplication.h>
#include <qfontdialog.h>
#include <qinputdialog.h>

void Editor::font()
{
	bool ok;
	QFont f = QFontDialog::getFont( &ok, e_->font() );
	if (ok) {
		e_->setFont( f );
		LOG("set font %s", (const char *) (f.family()).utf8());
		mwords_->setFont(f);
		mwords_->clear();
		mwords_->insertItem( "Start Spelling",   this, SLOT(spellAdvance()));
		mwords_->insertItem( "Ignore",   this, SLOT(spellIgnore()));
		mwords_->insertItem( "Add",   this, SLOT(spellAdd()));
		if (Global::instance()->fixeddict)
			mwords_->insertItem( "Add na&me",   this, SLOT(spellName()),   Qt::ALT+Qt::Key_M );
		mw1_ = mwords_->insertItem( " ",   this, SLOT(replaceWord1()), 0 );
		mw2_ = mwords_->insertItem( " ",   this, SLOT(replaceWord2()), 0 );
		mw3_ = mwords_->insertItem( " ",   this, SLOT(replaceWord3()), 0 );
		mw4_ = mwords_->insertItem( " ",   this, SLOT(replaceWord4()), 0 );
		mw5_ = mwords_->insertItem( " ",   this, SLOT(replaceWord5()), 0 );

	}
}

void Editor::colors() {
	cleanMWords();
	ColorDialog *cd = new ColorDialog();
	cd->setCaption("Set colors");
	if (!cd->exec()) {
		delete cd;
		return;
	}

	Global::instance()->c_background = cd->getBackground();
	Global::instance()->c_foreground = cd->getForeground();
	Global::instance()->c_highlight = cd->getHighlight();
	Global::instance()->c_tag1 = cd->getTag1();
	Global::instance()->c_tag2 = cd->getTag2();
	Global::instance()->c_tag3 = cd->getTag3();
	Global::instance()->c_tag4 = cd->getTag4();

	e_->setPaletteBackgroundColor(Global::instance()->c_background);
	e_->setPaletteForegroundColor(Global::instance()->c_foreground);
	QPalette qp = e_->palette();
	qp.setColor(QPalette::Active, QColorGroup::Highlight, Global::instance()->c_highlight);
	qp.setColor(QPalette::Inactive, QColorGroup::Highlight, Global::instance()->c_highlight);
	e_->setPalette(qp);
	e_->syntaxHighlighter()->rehighlight();

	tw_user_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_user_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_user_->setPalette(qp);

	tw_search_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_search_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_search_->setPalette(qp);

	tw_tags_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_tags_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_tags_->setPalette(qp);

	update();

	delete cd;

}

void Editor::editAlias() {
LOG("qwerty edit alias");
	cleanMWords();
	AliasDialog *ad = new AliasDialog();
	ad->setCaption("Edit Alias");
	if (!ad->exec()) {
		delete ad;
		return;
	}

	emain_->reloadAlias();
	eaux_->reloadAlias();
	delete ad;
	return;
}

void Editor::configWWW() {
LOG("qwerty www configuration");
	cleanMWords();
	WWWDialog *ad = new WWWDialog();
	ad->setCaption("WWW Configuration");
	if (!ad->exec()) {
		delete ad;
		return;
	}
	return;
}



void Editor::lockCtags() {
	LOG("qwerty lock ctags");
	cleanMWords();
	ctags_locked_ = true;
}

void Editor::unlockCtags() {
	LOG("qwerty lock ctags");
	cleanMWords();
	ctags_locked_ = false;
}

void Editor::configCtags() {
	LOG("qwerty config ctags");
	cleanMWords();
	CtagsDialog *d = new CtagsDialog();
	d->setCaption("ctags configuration");
	if (!d->exec()) {
		delete d;
		return;
	}

	Global::instance()->load_glibc_tags = d->getLibc();
	Global::instance()->load_posixh_tags = d->getPosixh();
	Global::instance()->load_latex_tags = d->getLatex();
	Global::instance()->generate_local_tags = d->getGenerateLocalTags();
	Global::instance()->tags_cmd = d->getCmd();

	QString cmd = Global::instance()->tags_cmd;
	if (Global::instance()->generate_local_tags && !cmd.isNull() && !cmd.isEmpty()) {
		msgScreen("ctags, please wait...");
		BCursor busy;
		QTUTILS::run_program(cmd, tw_user_, "local ctags generated");
		msgScreen("done", 2000);
	}

	printf("reloading ctags\n");
	thread_->startProcessing(QString("reload tags"));

	delete d;
	return;
}

void Editor::configLanguage() {
	LOG("qwerty config language");
	cleanMWords();
	QStringList lst;
	lst  << "English" << "Romanian (cedilla)" << "Romanian (commabelow)";
	bool ok;
	int lang = 1;
	Global *glb = Global::instance();

	// initial selection
	if (glb->lang_en)
		lang = 0;
	if (glb->lang_ro)
		lang = 1;
	if (glb->lang_ro_commabelow)
		lang = 2;

	// run the dialog
	QString res = QInputDialog::getItem(
	        "Spelling Dictionary", "Select language:", lst, lang, TRUE, &ok,
	        this );
	if ( ok ) {
		// user selected an item and pressed OK
		if (strcmp((const char *) res, "Romanian (cedilla)") == 0) {
			glb->lang_ro = true;
			glb->lang_ro_commabelow = false;
			glb->lang_en = false;
			if (lang == 0) {
				msgScreen("Using Romanian dictionary\n");
			}
		}
		if (strcmp((const char *) res, "Romanian (commabelow)") == 0) {
			glb->lang_ro = false;
			glb->lang_ro_commabelow = true;
			glb->lang_en = false;
			if (lang == 0) {
				msgScreen("Using Romanian dictionary\n");
			}
		}
		else if (strcmp((const char *) res, "English") == 0) {
			glb->lang_ro = false;
			glb->lang_ro_commabelow = false;
			glb->lang_en = true;
			if (lang != 0) {
				msgScreen("Using English dictionary\n");
			}
		}
		initDictionary();
	}
}

#define MAX_STR_STATUS 10000
void Editor::status() {
	char str[MAX_STR_STATUS + 1];

	QString fname = getFname();
	Q3CString ufname = fname.utf8();
	const char *csname = ufname;

	const char *sformat = ff_str(b_->getActiveFormat());

	int lines = e_->numLines();

	char speller_stats[100];
	Stats::instance()->sprint(speller_stats, 100);

	QFont fnt = e_->font();
	const char *ffamily = (const char *) fnt.family().ascii();

	int para;
	int index;
	e_->getCursorPosition(&para, &index);

	snprintf(str, MAX_STR_STATUS, "\n    rospell version %s    \n\n    File: %s\n    Loaded as: %s\n"
		    "    Lines: %d\n\n"
		    "    Font family: %s    \n"
		    "    Font test: ăşâţîĂŞÂŢÎșȘțȚ    \n"
		    "\n%s    Dictionary: %s, %s\n\n"
		    "    %d ctags\n"
		    "    Cursor: %d/%d\n"
		    "    Global make command: %s\n",
		    VERSION, csname, sformat, lines, ffamily, speller_stats,
		    (Global::instance()->lang_en)? "English": "Romanian",
		    (pdict_ == 0)? "not loaded":"loaded",
		    thread_->getTagsNumber(), para + 1, index + 1,
		    (Global::instance()->make_cmd_.isEmpty())? "not set": (const char *) Global::instance()->make_cmd_);

	char *str2 = str + strlen(str);
	unsigned len = MAX_STR_STATUS - strlen(str);
	if(pdict_ != 0) {
		DbDict *hptr = pdict_->getMaster();
		unsigned c1 = hptr->wordCount();
		DbUser *uptr = pdict_->getUser();
		unsigned c2 = uptr->wordCount();
		DbUser *iptr = pdict_->getIgnore();
		unsigned c3 = iptr->wordCount();
		DbUser *fptr = pdict_->getFixed();
		unsigned c4 = fptr->wordCount();

		snprintf(str2, len, "\n    Master Dict %u words\n"
		                          "    User Dict %u words\n"
		                          "    Ignore Dict %u words\n"
		                          "    Fixed Dict %u words\n",
		                          c1, c2, c3, c4);
	}

	StatusDialog *sd = new StatusDialog(fnt, str);
	sd->setCaption("File status");
	sd->exec();
//	QMessageBox::warning(0,"File status", str);
	delete sd;
}

void Editor::editF1() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF1.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF2() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF2.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF3() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF3.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF4() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF4.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::fileOptions() {
	FileOptionsDialog *fo = new FileOptionsDialog();
	fo->setCaption("File Options");
	fo->exec();
	delete fo;
}

==> rospell-2009.00-rc2.tar.gz: rospell-2009.00-rc2/src/rospell/qoptions.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include "qwerty.h"
#include "briefedit.h"
#include "dialogs.h"
#include "colordialog.h"
#include "aliasdialog.h"
#include "ctagsdialog.h"
#include "wwwdialog.h"
#include "hashdb.h"
#include "spell.h"
#include "qtutils.h"
#include "busycursor.h"
#include "ctags.h"
#include "bufmgr.h"
#include "gdb.h"
#include "statusfield.h"
#include <qapplication.h>
#include <qfontdialog.h>
#include <qinputdialog.h>
#ifdef USING_QT4
#include <Q3CString>
#endif

void Editor::setSpellerBar() {
	mwords_->insertItem( tr("Start"),   this, SLOT(spellAdvance()));
	mwords_->insertItem( tr("Ignore"),   this, SLOT(spellIgnore()));
	mwords_->insertItem( tr("Add"),   this, SLOT(spellAdd()));
	mw1_ = mwords_->insertItem( " ",   this, SLOT(replaceWord1()), 0 );
	mw2_ = mwords_->insertItem( " ",   this, SLOT(replaceWord2()), 0 );
	mw3_ = mwords_->insertItem( " ",   this, SLOT(replaceWord3()), 0 );
	mw4_ = mwords_->insertItem( " ",   this, SLOT(replaceWord4()), 0 );
	mw5_ = mwords_->insertItem( " ",   this, SLOT(replaceWord5()), 0 );
}

void Editor::font()
{
	bool ok;
	QFont f = QFontDialog::getFont( &ok, e_->font() );
	if (ok) {
		emain_->setFont(f);
		eaux_->setFont(f);
		tw_user_->setFont(f);
		tw_tags_->setFont(f);
		tw_search_->setFont(f);
		tw_bookmarks_->setFont(f);
		tw_hex_->setFont(f);
		LOG("set font %s", (const char *) (f.family()).utf8());
		mwords_->setFont(f);
		mwords_->clear();
		setSpellerBar();
	}
}

void Editor::colors() {
	cleanMWords();
	ColorDialog *cd = new ColorDialog();
	cd->setCaption(tr("Colors"));
	if (!cd->exec()) {
		delete cd;
		return;
	}

	Global::instance()->c_background = cd->getBackground();
	Global::instance()->c_foreground = cd->getForeground();
	Global::instance()->c_highlight = cd->getHighlight();
	Global::instance()->c_tag1 = cd->getTag1();
	Global::instance()->c_tag2 = cd->getTag2();
	Global::instance()->c_tag3 = cd->getTag3();
	Global::instance()->c_tag4 = cd->getTag4();

	emain_->setPaletteBackgroundColor(Global::instance()->c_background);
	emain_->setPaletteForegroundColor(Global::instance()->c_foreground);
	QPalette qp = emain_->palette();
	qp.setColor(QPalette::Active, QColorGroup::Highlight, Global::instance()->c_highlight);
	qp.setColor(QPalette::Inactive, QColorGroup::Highlight, Global::instance()->c_highlight);
	emain_->setPalette(qp);
	emain_->syntaxHighlighter()->rehighlight();

	eaux_->setPaletteBackgroundColor(Global::instance()->c_background);
	eaux_->setPaletteForegroundColor(Global::instance()->c_foreground);
	qp = eaux_->palette();
	qp.setColor(QPalette::Active, QColorGroup::Highlight, Global::instance()->c_highlight);
	qp.setColor(QPalette::Inactive, QColorGroup::Highlight, Global::instance()->c_highlight);
	eaux_->setPalette(qp);
	eaux_->syntaxHighlighter()->rehighlight();

	tw_user_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_user_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_user_->setPalette(qp);

	tw_search_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_search_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_search_->setPalette(qp);

	tw_tags_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_tags_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_tags_->setPalette(qp);

	tw_bookmarks_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_bookmarks_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_bookmarks_->setPalette(qp);

	tw_hex_->setPaletteBackgroundColor(Global::instance()->c_background);
	tw_hex_->setPaletteForegroundColor(Global::instance()->c_foreground);
	tw_hex_->setPalette(qp);

	dirfiles_->setPaletteBackgroundColor(Global::instance()->c_background);
	dirfiles_->setPaletteForegroundColor(Global::instance()->c_foreground);
	dirfiles_->setPalette(qp);

	update();

	delete cd;

}

void Editor::editAlias() {
LOG("qwerty edit alias");
	cleanMWords();
	AliasDialog *ad = new AliasDialog();
	ad->setCaption(tr("Alias"));
	if (!ad->exec()) {
		delete ad;
		return;
	}

	emain_->reloadAlias();
	eaux_->reloadAlias();
	delete ad;
	return;
}

void Editor::configWWW() {
LOG("qwerty www configuration");
	cleanMWords();
	WWWDialog *ad = new WWWDialog();
	ad->setCaption(tr("HTTP Proxy"));
	if (!ad->exec()) {
		delete ad;
		return;
	}
	return;
}



void Editor::lockCtags() {
	LOG("qwerty lock ctags");
	cleanMWords();
	ctags_locked_ = true;
}

void Editor::unlockCtags() {
	LOG("qwerty lock ctags");
	cleanMWords();
	ctags_locked_ = false;
}

void Editor::configCtags() {
	LOG("qwerty config ctags");
	cleanMWords();
	CtagsDialog *d = new CtagsDialog();
	d->setCaption(tr("Ctags"));
	if (!d->exec()) {
		delete d;
		return;
	}

	Global::instance()->load_glibc_tags = d->getLibc();
	Global::instance()->load_posixh_tags = d->getPosixh();
	Global::instance()->load_latex_tags = d->getLatex();
	Global::instance()->generate_local_tags = d->getGenerateLocalTags();
	Global::instance()->tags_cmd = d->getCmd();

	QString cmd = Global::instance()->tags_cmd;
	if (Global::instance()->generate_local_tags && !cmd.isNull() && !cmd.isEmpty()) {
		msgScreen(tr("ctags, please wait..."));
		BCursor busy;
		QTUTILS::run_program(cmd, tw_user_, (char *) (const char *) tr("local ctags generated"));
		msgScreen(tr("done"), 2000);
	}

	thread_->startProcessing(QString("reload tags")); // do not translate this!

	delete d;
	return;
}

void Editor::configLanguage() {
	LOG("qwerty config language");
	cleanMWords();
	msgScreen("");
	QStringList lst;
	for (int i = 0; i < MAX_LANG_DEF; i++)
		lst << getLangName(i);
	bool ok;
	Global *glb = Global::instance();

	// run the dialog
	QString res = QInputDialog::getItem(
	        tr("Language"), tr("Select language: "), lst, glb->lang, TRUE, &ok,
	        this );
	if ( ok ) {
		// user selected an item and pressed OK
		QString msg = QString(tr("Dictionary: ")) + res;
		glb->lang = getLangId(res);
		initDictionary();
		msgScreen(msg);
	}
	lang_->setText(getLangName(Global::instance()->lang));
	
}

#define MAX_STR_STATUS 10000
void Editor::status() {
	char str[MAX_STR_STATUS + 1];

	QString fname = getFname();
	Q3CString ufname = fname.utf8();
	const char *csname = ufname;

	const char *sformat = ff_str(b_->getActiveFormat());

	int lines = e_->numLines();

	char speller_stats[100];
	Stats::instance()->sprint(speller_stats, 100);

	QFont fnt = e_->font();
	const char *ffamily = (const char *) fnt.family().ascii();

	int para;
	int index;
	e_->getCursorPosition(&para, &index);

	snprintf(str, MAX_STR_STATUS, "\n    rospell version %s    \n\n    File: %s\n    Loaded as: %s\n"
		    "    Lines: %d\n\n"
		    "    Font family: %s    \n"
		    "    Font test: ăşâţîĂŞÂŢÎșȘțȚ    \n"
		    "\n%s    Dictionary: %s, %s\n\n"
		    "    %d ctags\n"
		    "    gdb thread %s\n"
		    "    Cursor: %d/%d\n"
		    "    Global make command: %s\n"
		    "    Global gdb command: %s\n",
		    VERSION, csname, sformat, lines, ffamily, speller_stats,
		    (const char *) getLangName(Global::instance()->lang),
		    (pdict_ == 0)? "not loaded":"loaded",
		    thread_->getTagsNumber(),
		    (gthread_->isActive() == false)? "inactive": "active",
		    para + 1, index + 1,
		    (Global::instance()->make_cmd_.isEmpty())? "not set": (const char *) Global::instance()->make_cmd_,
		    (Global::instance()->gdb_cmd_.isEmpty())? "not set": (const char *) Global::instance()->gdb_cmd_);

	char *str2 = str + strlen(str);
	unsigned len = MAX_STR_STATUS - strlen(str);
	if(pdict_ != 0) {
		DbDict *hptr = pdict_->getMaster();
		unsigned c1 = hptr->wordCount();
		DbUser *uptr = pdict_->getUser();
		unsigned c2 = uptr->wordCount();
		DbUser *iptr = pdict_->getIgnore();
		unsigned c3 = iptr->wordCount();

		snprintf(str2, len, "\n    Master Dict %u words\n"
		                          "    User Dict %u words\n"
		                          "    Ignore Dict %u words\n",
		                          c1, c2, c3);
	}

	StatusDialog *sd = new StatusDialog(fnt, str);
	sd->setCaption(tr("Status"));
	sd->exec();
//	QMessageBox::warning(0,"File status", str);
	delete sd;
}

void Editor::editF1() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF1.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF2() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF2.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF3() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF3.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::editF4() {
	cleanMWords();
	QString fname = Global::unixHomeConvert("~/.rospell/userF4.sh");
	load(fname, true);
	save();
	QString chmod_str = "chmod +x " + fname;
	char *retval = UTILS::run_prg_malloc((const char *) chmod_str);
	delete [] retval;
}

void Editor::fileOptions() {
	FileOptionsDialog *fo = new FileOptionsDialog();
	fo->setCaption(tr("Options"));
	fo->exec();
	delete fo;
}

void Editor::customize() {
	CustomizeDialog *c = new CustomizeDialog();
	c->setCaption(tr("Customize"));
	if (!c->exec()) {
		delete c;
		return;
	}

	Global::instance()->toolbar_ = c->getToolbar();
	if (Global::instance()->toolbar_) {
		tool1_->show();
		tool2_->show();
		tool3_->show();
		tool4_->show();
	}
	else {
		tool1_->hide();
		tool2_->hide();
		tool3_->hide();
		tool4_->hide();
	}
	delete c;
}
